@@ -439,9 +439,9 @@ class CloudvectorDAST(object):
                 if param in params_to_validate:
                     for condition, to_check in params_to_validate[param].items():
                         if condition == "missing":
-                            validations.append([str(param) + "_missing", str(param) + " = ''", to_check])
+                            validations.append([str(param) + "_missing", str(param) + "_arg = ''", to_check])
                         elif condition == "invalid":
-                            validations.append([str(param) + "_invalid", str(param) + " = 'iamdummy'", to_check])
+                            validations.append([str(param) + "_invalid", str(param) + "_arg = 'iamdummy'", to_check])
         return validations
 
     def create_pytest_methods(self, cv_events, custom_validations):
@@ -459,7 +459,7 @@ class CloudvectorDAST(object):
                 if _[1]["attributes"]["http_rsp_status_code"] not in ["200", "201"]:
                     continue
             if event["url"]:
-                api = str(event["http-req-url"]).lower().lstrip("/").rstrip("/").replace("/", "_").replace("-", "_").split("?")[
+                api = str(event["http-req-url"]).lstrip("/").rstrip("/").replace("/", "_").replace("-", "_").split("?")[
                     0]
                 if api not in apis_to_be_tested:
                     apis_to_be_tested[api] = {}
@@ -662,23 +662,23 @@ class CloudvectorDAST(object):
             # if not to_skip:
             # print(event)
             if str(event["attributes"]["http_path"]).lower() not in self.params_captured_in_traffic:
-                self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()] = {}
+                self.params_captured_in_traffic[str(event["attributes"]["http_path"])] = {}
 
             # print("\n\n\n\n\n\n\n")
             for param, value in req_params_found.items():
                 # if "severity" in param:
                 #     print(str(event) + "\n\n")
-                if param in self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()]:
+                if param in self.params_captured_in_traffic[str(event["attributes"]["http_path"])]:
                     # self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()] = {}
-                    if value not in self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()][
+                    if value not in self.params_captured_in_traffic[str(event["attributes"]["http_path"])][
                         param]:
-                        self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()][param].append(
+                        self.params_captured_in_traffic[str(event["attributes"]["http_path"])][param].append(
                             value)
                 else:
-                    self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()][param] = [value]
+                    self.params_captured_in_traffic[str(event["attributes"]["http_path"])][param] = [value]
                 try:
-                    self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()][param] = \
-                        list(set(self.params_captured_in_traffic[str(event["attributes"]["http_path"]).lower()][param]))
+                    self.params_captured_in_traffic[str(event["attributes"]["http_path"])][param] = \
+                        list(set(self.params_captured_in_traffic[str(event["attributes"]["http_path"])][param]))
                 except TypeError:
                     pass
             cv_requests.append([request, event])
@@ -750,6 +750,9 @@ def main():
             enable_fuzzing = True
     CloudvectorDAST(str(input_spec_one).strip(), str(input_spec_two).strip(), ce_host, ce_username, ce_password, config,
                     str(cover_only_diff).lower(), input_params_file, enable_fuzzing)
+    print("\n Test generation complete! Making the pycode PEP complaint ( https://www.python.org/dev/peps/pep-0008/ ).....\n")
+    os.system("autopep8 --in-place --aggressive --aggressive tests/*")
+    print("\n\t\t..........done")
 
 
 if __name__ == "__main__":
